import io
import json

import ruamel.yaml
import toml


__version__ = "0.1.1"  # DO NOT EDIT THIS LINE MANUALLY. LET bump2version UTILITY DO IT


def format_json(unformatted: str) -> str:
    parsed = json.loads(unformatted)
    return json.dumps(parsed, indent=2) + "\n"


def format_toml(unformatted: str) -> str:
    parsed = toml.loads(unformatted, decoder=toml.TomlPreserveCommentDecoder())
    return toml.dumps(parsed, encoder=toml.TomlPreserveCommentEncoder())


def format_yaml(unformatted: str) -> str:
    yaml = ruamel.yaml.YAML()
    # Make sure to always have `sequence >= offset + 2`
    yaml.indent(mapping=2, sequence=2, offset=0)

    parsed = yaml.load(unformatted)
    dump_stream = io.StringIO()
    yaml.dump(parsed, stream=dump_stream)
    return dump_stream.getvalue()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mdformat_config']

package_data = \
{'': ['*']}

install_requires = \
['mdformat>=0.1.2', 'ruamel.yaml>=0.16.0', 'toml>=0.10.0']

entry_points = \
{'mdformat.codeformatter': ['json = mdformat_config:format_json',
                            'toml = mdformat_config:format_toml',
                            'yaml = mdformat_config:format_yaml']}

setup_kwargs = {
    'name': 'mdformat-config',
    'version': '0.1.1',
    'description': 'Mdformat plugin to beautify configuration and data-serialization formats',
    'long_description': '[![Build Status](https://github.com/hukkinj1/mdformat-config/workflows/Tests/badge.svg?branch=master)](<https://github.com/hukkinj1/mdformat-config/actions?query=workflow%3ATests+branch%3Amaster+event%3Apush>)\n[![PyPI version](https://badge.fury.io/py/mdformat-config.svg)](<https://badge.fury.io/py/mdformat-config>)\n\n# mdformat-config\n> Mdformat plugin to beautify configuration and data-serialization formats\n\n## Description\nmdformat-config is an [mdformat](https://github.com/executablebooks/mdformat) plugin\nthat makes mdformat beautify configuration and data-serialization formats.\nCurrently supported formats are JSON, TOML and YAML.\n\n## Usage\nInstall with:\n```console\npip install mdformat-config\n```\n',
    'author': 'Taneli Hukkinen',
    'author_email': 'hukkinj1@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/hukkinj1/mdformat-config',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
